@@ -42,6 +42,7 @@ from core.threads import threadMgr
 from core import geo
 from core import modrana_log
 from core import utils
+from core import paths
 
 import logging
 log = logging.getLogger("mod.gui.qt5")
@@ -142,6 +143,9 @@ class QMLGUI(GUIModule):
         # log for log messages from the QML context
         self.qml_log = qml_log
 
+        # tracklogs
+        self.tracklogs = Tracklogs(self)
+
     def firstTime(self):
         # trigger the first time signal
         self.firstTimeSignal()
@@ -325,7 +329,8 @@ class QMLGUI(GUIModule):
             "nmeaFilePath" : self.get("NMEAFilePath", None),
             "layerTree" : self.modules.mapLayers.getLayerTree(),
             "dictOfLayerDicts" : self.modules.mapLayers.getDictOfLayerDicts(),
-            "themesFolderPath" : os.path.abspath(self.modrana.paths.getThemesFolderPath())
+            "themesFolderPath" : os.path.abspath(self.modrana.paths.getThemesFolderPath()),
+            "sailfish" : self.dmod.getDeviceIDString() == "jolla"
         }
         return values
 
@@ -762,3 +767,46 @@ class Theme(object):
         }
         self._themeDict = themeDict
         return themeDict
+
+class Tracklogs(object):
+    """Some tracklog specific functionality"""
+
+    SAILFISH_TRACKLOGS_SYMLINK_NAME = "modrana_tracklogs"
+    SAILFISH_SYMLINK_PATH = os.path.join(paths.getHOMEPath(), "Documents", SAILFISH_TRACKLOGS_SYMLINK_NAME)
+
+    def __init__(self, gui):
+        self.gui = gui
+
+    def sailfishSymlinkExists(self):
+        """Report if the easy access symlink on Sailfish OS for tracklogs exists
+
+        :returns: True if the symlink exists, False if not
+        :rtype: bool
+        """
+        return os.path.islink(self.SAILFISH_SYMLINK_PATH)
+
+    def createSailfishSymlink(self):
+        """Create symlink from the actual tracklogs folder in the XDG path
+        to ~/Documents for easier access to the tracklogs by the users
+        """
+        self.gui.log.info("tracklogs: creating sailfish tracklogs symlink")
+        if self.sailfishSymlinkExists():
+            self.gui.log.warning("tracklogs: the Sailfish tracklogs symlink already exists")
+        else:
+            try:
+                os.symlink(self.gui.modrana.paths.getTracklogsFolderPath(), self.SAILFISH_SYMLINK_PATH)
+                self.gui.log.info("tracklogs: sailfish tracklogs symlink created")
+            except Exception:
+                self.gui.log.exception("tracklogs: sailfish tracklogs symlink creation failed")
+
+    def removeSailfishSymlink(self):
+        """Remove the easy-access Sailfish OS symlink"""
+        self.gui.log.info("tracklogs: removing sailfish tracklogs symlink")
+        if not self.sailfishSymlinkExists():
+            self.gui.log.warning("tracklogs: the Sailfish tracklogs symlink does not exist")
+        else:
+            try:
+                os.remove(self.SAILFISH_SYMLINK_PATH)
+                self.gui.log.info("tracklogs: sailfish tracklogs symlink removed")
+            except Exception:
+                self.gui.log.exception("tracklogs: sailfish tracklogs symlink removed")
