@@ -745,10 +745,10 @@ class Options(RanaModule):
         group = addGroup("Routing", "routing", catNavigation, "generic")
 
         addOpt("Routing provider", "routingProvider",
-               [("GoogleDirections", "Google - <b>online</b>"),
-                ("Monav", "Monav - <b>on device</b>")],
+               [(constants.ROUTING_PROVIDER_GOOGLE, "Google - <b>online</b>"),
+                (constants.ROUTING_PROVIDER_MONAV, "Monav - <b>on device</b>")],
                group,
-               "GoogleDirections")
+               constants.DEFAULT_ROUTING_PROVIDER)
 
         addBoolOpt("Avoid major highways", "routingAvoidHighways", group, False)
 
